@@ -1,7 +1,8 @@
 # vat.py - functions for handling European VAT numbers
 # coding: utf-8
 #
-# Copyright (C) 2012, 2013 Arthur de Jong
+# Copyright (C) 2012-2015 Arthur de Jong
+# Copyright (C) 2015 Lionel Elie Mamane
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -39,13 +40,13 @@ that country.
 """
 
 from stdnum.exceptions import *
-from stdnum.util import clean
+from stdnum.util import clean, get_vat_module
 
 
 country_codes = set([
     'at', 'be', 'bg', 'cy', 'cz', 'de', 'dk', 'ee', 'es', 'fi', 'fr', 'gb',
-    'gr', 'hr', 'hu', 'ie', 'it', 'lt', 'lu', 'lv', 'mt', 'nl', 'pl', 'pt', 'ro',
-    'se', 'si', 'sk'
+    'gr', 'hr', 'hu', 'ie', 'it', 'lt', 'lu', 'lv', 'mt', 'nl', 'pl', 'pt',
+    'ro', 'se', 'si', 'sk',
 ])
 """The collection of country codes that are queried. Greece is listed with
 a country code of gr while for VAT purposes el is used instead."""
@@ -68,10 +69,7 @@ def _get_cc_module(cc):
     if cc not in country_codes:
         return
     if cc not in _country_modules:
-        # do `from stdnum.CC import vat` instead of `import stdnum.CC.vat`
-        # to handle the case where vat is an alias
-        _country_modules[cc] = __import__(
-            'stdnum.%s' % cc, globals(), locals(), ['vat']).vat
+        _country_modules[cc] = get_vat_module(cc)
     return _country_modules[cc]
 
 
@@ -114,6 +112,27 @@ def guess_country(number):
             if _get_cc_module(cc).is_valid(number)]
 
 
+def _get_client():  # pragma: no cover (no tests for this function)
+    """Get a SOAP client for performing VIES requests."""
+    # this function isn't automatically tested because the functions using
+    # it are not automatically tested
+    global _vies_client
+    if not _vies_client:
+        try:
+            from urllib import getproxies
+        except ImportError:
+            from urllib.request import getproxies
+        # try suds first
+        try:
+            from suds.client import Client
+            _vies_client = Client(vies_wsdl, proxy=getproxies()).service
+        except ImportError:
+            # fall back to using pysimplesoap
+            from pysimplesoap.client import SoapClient
+            _vies_client = SoapClient(wsdl=vies_wsdl, proxy=getproxies())
+    return _vies_client
+
+
 def check_vies(number):  # pragma: no cover (no tests for this function)
     """Queries the online European Commission VAT Information Exchange
     System (VIES) for validity of the provided number. Note that the
@@ -122,12 +141,19 @@ def check_vies(number):  # pragma: no cover (no tests for this function)
     # this function isn't automatically tested because it would require
     # network access for the tests and unnecessarily load the VIES website
     number = compact(number)
-    global _vies_client
-    if not _vies_client:
-        from suds.client import Client
-        try:
-            from urllib import getproxies
-        except ImportError:
-            from urllib.request import getproxies
-        _vies_client = Client(vies_wsdl, proxy=getproxies())
-    return _vies_client.service.checkVat(number[:2], number[2:])
+    return _get_client().checkVat(number[:2], number[2:])
+
+
+def check_vies_approx(number, requester):  # pragma: no cover
+    """Queries the online European Commission VAT Information Exchange System
+    (VIES) for validity of the provided number, providing a validity
+    certificate as proof. You will need to give your own VAT number for this
+    to work. Note that the service has usage limitations (see the VIES
+    website for details). This returns a dict-like object."""
+    # this function isn't automatically tested because it would require
+    # network access for the tests and unnecessarily load the VIES website
+    number = compact(number)
+    requester = compact(requester)
+    return _get_client.checkVatApprox(
+        countryCode=number[:2], vatNumber=number[2:],
+        requesterCountryCode=requester[:2], requesterVatNumber=requester[2:])
