@@ -22,3 +22,5 @@
 
 # provide vat as an alias
 from stdnum.fi import alv as vat
+from stdnum.fi import ytunnus as businessid
+from stdnum.fi import hetu as personalid
