@@ -72,11 +72,11 @@ def imei_type(number):
     invalid) for checking the type of number passed."""
     try:
         number = validate(number)
-    except Exception:
+    except ValidationError:
         return None
     if len(number) in (14, 15):
         return 'IMEI'
-    elif len(number) == 16:
+    else:  # len(number) == 16:
         return 'IMEISV'
 
 
